@@ -221,7 +221,7 @@ class App(object):
                 input.update({'__data__': body})  # 非 json 请求体
 
             # input4str 方便 cache
-            if 'str' in str(func.__annotations__):
+            if 'str' in str(func.__annotations__): # todo: cachek可支持dict 取消判断
                 input = str(input)  # json.loads
             elif 'tuple' in str(func.__annotations__):
                 input = tuple(input.items())  # dict
